@@ -13,10 +13,10 @@ class Team(object):
             parent_id (int):
         """
 
-        self.id = team_id
+        self.id = int(team_id)
         self.name = name
         self.full_name = full_name
-        self.parent_id = parent_id
+        self.parent_id = int(parent_id)
 
     def __str__(self):
         return """Team(team_id={}, name={}, full_name={}, parent_id={})""".format(
