@@ -23,11 +23,12 @@ class OsaAPI(object):
     """
     max_try = CxConfig.CxConfig.config.max_try
     base_url = CxConfig.CxConfig.config.url
+    verify = CxConfig.CxConfig.config.verify
 
     def __init__(self):
         self.retry = 0
 
-    def get_all_osa_scan_details_for_project(self, project_id=None, page=None, items_per_page=None):
+    def get_all_osa_scan_details_for_project(self, project_id=None, page=1, items_per_page=100):
         """
         Get basic scan details for all CxOSA scans associated with a specified project Id.
         v8.4.2 and up
@@ -55,11 +56,12 @@ class OsaAPI(object):
         if items_per_page:
             optionals.append("items_per_page=" + str(items_per_page))
         if optionals:
+            osa_scans_url += "&"
             osa_scans_url += "&".join(optionals)
 
         headers = copy.deepcopy(AuthenticationAPI.AuthenticationAPI.auth_headers)
 
-        r = requests.get(url=osa_scans_url, headers=headers)
+        r = requests.get(url=osa_scans_url, headers=headers, verify=OsaAPI.verify)
         if r.status_code == 200:
             a_list = r.json()
             osa_scan_details = [
@@ -129,7 +131,8 @@ class OsaAPI(object):
 
         osa_scan_by_scan_id_url = self.base_url + "/osa/scans/{scanId}".format(scanId=scan_id)
 
-        r = requests.get(url=osa_scan_by_scan_id_url, headers=AuthenticationAPI.AuthenticationAPI.auth_headers)
+        r = requests.get(url=osa_scan_by_scan_id_url, headers=AuthenticationAPI.AuthenticationAPI.auth_headers,
+                         verify=OsaAPI.verify)
 
         if r.status_code == 200:
             a_dict = r.json()
@@ -194,7 +197,7 @@ class OsaAPI(object):
 
         osa_scans_url = self.base_url + "/osa/scans" + "?projectId=" + str(project_id)
 
-        r = requests.post(url=osa_scans_url, headers=headers, data=m)
+        r = requests.post(url=osa_scans_url, headers=headers, data=m, verify=OsaAPI.verify)
         if r.status_code == 202:
             scan_id = r.json().get("scanId")
         elif r.status_code == http.HTTPStatus.BAD_REQUEST:
@@ -228,7 +231,8 @@ class OsaAPI(object):
 
         osa_file_extensions_url = self.base_url + "/osa/fileextensions"
 
-        r = requests.get(url=osa_file_extensions_url, headers=AuthenticationAPI.AuthenticationAPI.auth_headers)
+        r = requests.get(url=osa_file_extensions_url, headers=AuthenticationAPI.AuthenticationAPI.auth_headers,
+                         verify=OsaAPI.verify)
         if r.status_code == 200:
             file_extensions = r.text
         elif r.status_code == http.HTTPStatus.BAD_REQUEST:
@@ -264,7 +268,11 @@ class OsaAPI(object):
 
         osa_licenses_url = self.base_url + "/osa/licenses" + "?scanId=" + str(scan_id)
 
-        r = requests.get(url=osa_licenses_url, headers=AuthenticationAPI.AuthenticationAPI.auth_headers)
+        r = requests.get(
+            url=osa_licenses_url,
+            headers=AuthenticationAPI.AuthenticationAPI.auth_headers,
+            verify=OsaAPI.verify
+        )
         if r.status_code == 200:
             a_list = r.json()
             licenses = [
@@ -295,7 +303,7 @@ class OsaAPI(object):
 
         return licenses
 
-    def get_osa_scan_libraries(self, scan_id, page=None, items_per_page=None):
+    def get_osa_scan_libraries(self, scan_id, page=1, items_per_page=100):
         """
         Get all the used libraries details for the specified CxOSA scan Id.
         Supported v8.6.0 and up
@@ -323,9 +331,14 @@ class OsaAPI(object):
         if items_per_page:
             optionals.append("items_per_page=" + str(items_per_page))
         if optionals:
+            osa_libraries_url += "&"
             osa_libraries_url += "&".join(optionals)
 
-        r = requests.get(url=osa_libraries_url, headers=AuthenticationAPI.AuthenticationAPI.auth_headers)
+        r = requests.get(
+            url=osa_libraries_url,
+            headers=AuthenticationAPI.AuthenticationAPI.auth_headers,
+            verify=OsaAPI.verify
+        )
 
         if r.status_code == 200:
             a_list = r.json()
@@ -383,7 +396,7 @@ class OsaAPI(object):
 
         return libraries
 
-    def get_osa_scan_vulnerabilities_by_id(self, scan_id, page=None, items_per_page=None, library_id=None,
+    def get_osa_scan_vulnerabilities_by_id(self, scan_id, page=1, items_per_page=100, library_id=None,
                                            state_id=None, comment=None, since=None, until=None):
         """
         Get all the vulnerabilities for the specified CxOSA scan Id.
@@ -431,9 +444,14 @@ class OsaAPI(object):
             if until:
                 optionals.append("until=" + str(until))
             if optionals:
+                osa_vulnerabilities_url += "&"
                 osa_vulnerabilities_url += "&".join(optionals)
 
-        r = requests.get(url=osa_vulnerabilities_url, headers=AuthenticationAPI.AuthenticationAPI.auth_headers)
+        r = requests.get(
+            url=osa_vulnerabilities_url,
+            headers=AuthenticationAPI.AuthenticationAPI.auth_headers,
+            verify=OsaAPI.verify
+        )
         if r.status_code == 200:
             a_list = r.json()
             vulnerabilities = [
@@ -515,8 +533,11 @@ class OsaAPI(object):
 
         osa_vulnerability_comment_url += "?projectId=" + str(project_id)
 
-        r = requests.get(url=osa_vulnerability_comment_url,
-                         headers=AuthenticationAPI.AuthenticationAPI.auth_headers)
+        r = requests.get(
+            url=osa_vulnerability_comment_url,
+            headers=AuthenticationAPI.AuthenticationAPI.auth_headers,
+            verify=OsaAPI.verify
+        )
 
         if r.status_code == 200:
             a_list = r.json()
@@ -560,7 +581,11 @@ class OsaAPI(object):
 
         osa_reports_url = self.base_url + "/osa/reports" + "?scanId=" + str(scan_id)
 
-        r = requests.get(url=osa_reports_url, headers=AuthenticationAPI.AuthenticationAPI.auth_headers)
+        r = requests.get(
+            url=osa_reports_url,
+            headers=AuthenticationAPI.AuthenticationAPI.auth_headers,
+            verify=OsaAPI.verify
+        )
 
         if r.status_code == 200:
             a_dict = r.json()
